# This configuration file is Python code.  You should not
# need to change it; but if you do, you need to know that
# in Python, the *indentation matters*.

# The following will normally be empty lists, like this:
#
#ignore_ADCPs = []
#ignore_other_sensors = []
#
# But if you want to run with only a subset of the ADCPs
# and/or ancillary sensors that are defined in this file,
# you can list the ones you want to ignore like this:
#
#ignore_ADCPs = ['wh300', 'os75']
#ignore_other_sensors = ['GPS']
#
# In this case, you are listing the 'instrument' field of each
# ADCP or sensor you wish to exclude.
#

ignore_ADCPs = []
ignore_other_sensors = []


# 2-letter abbreviation for logging file prefix and constructing dbase name;
# read by procsetup.py

shipabbrev = "hi"

ADCPs = [
        { 'instrument'  :  'os75',
          'setup'       :  'rdi_setup',
          'terminal'    :  'oswh_term',
          'defaultcmd'  :  'os75_default.cmd',
          'commands'    :  ('EA04500',),
          'datatypes'   :  ('os75bb', 'os75nb'),
          'wakeup_baud' :  9600
        }
        ]

common_opts = '-f %s -F -m 1 -H 2 ' % (shipabbrev,)
nb_opts =   '-rlE -c -I'          # raw data, write a log file, log errors
oswh_opts = '-rlE -c -O -I'       # -O for OS/WH data format
                                  # -c for checksum, -I to initiate pinging


# In the following list of "sensors" (which are simply serial streams
# being logged) the ADCPs must come first, and they must come in
# the same order as in the ADCPs list above; that is, there must
# be a 1:1 correspondence between the instrument fields in the
# ADCPs list and those in the first entries in the sensors list.


sensors = [

        { 'instrument'  :  'os75',       # Passive logging of OS
          'device'      :  'ttyS0',
          'baud'        :   19200,       # Some errors at 115200.
          'format'      :  'binary',
          'subdir'      :  'os75',
          'ext'         :  'raw',
          'opt'         :  oswh_opts}, # Note -I option for new ser_bin.


        { 'instrument'  :  'GPS',         #bridge gps
          'device'      :  'tty_dgnc_0_3',
          'baud'        :   4800,
          'format'      :  'ascii',
          'subdir'      :  'gpsnav',
          'ext'         :  'gps',
          'strings'     :  ('$GPGGA',),
          'messages'    :  ('gps',),
          'opt'         :  '-t'},       # GGA message has no checksum!


        { 'instrument'  :  'POS/MV',
          'device'      :  'tty_dgnc_0_2',   
          'baud'        :   9600,
          'format'      :  'ascii',
          'subdir'      :  'posmv',
          'ext'         :  'pmv',
          'strings'     :  ('$INGGA', '$PASHR'),
          'messages'    :  ('gps', 'pmv'),
          'opt'         :  '-tc'},



        ## gyro with checksum is "hdg"
        ## gyro without checksum is "hnc".
        ## Whichever is chosen must match in 'ext' and 'messages' here,
        ##          and the "best heading rule" suffix in cruise_cfg.m__

#        { 'instrument'  :  'Gyro Comparitor',
#          'device'      :  'ttyn1',          #'ttyn1b',
#          'baud'        :   4800,
#          'format'      :  'ascii',
#          'subdir'      :  'gyro_comparitor',
#          'ext'         :  'hnc',         ## hnc or hdg (must match 'messages')
#          'strings'     :  ('$HEHDT',),
#          'messages'    :  ('hnc',),      ## hnc or hdg (must match 'ext')
#          'opt'         :  '-t -s5'},      ## 6Hz: take every 3rd message (-s3)
                                          ##  no checksum on these

# data stopped coming in during Jan 2010 inport. switching to the other for primary

        { 'instrument'  :  'Sperry Gyro 1',
          'device'      :  'tty_dgnc_0_4', 
          'baud'        :   4800,
          'format'      :  'ascii',
          'subdir'      :  'othergyro',
          'ext'         :  'hnc',         ## hnc or hdg (must match 'messages')
          'strings'     :  ('$HEHDT',),
          'messages'    :  ('hnc',),      ## hnc or hdg (must match 'ext')
          'opt'         :  '-t -s5'},      ## 6Hz: take every 3rd message (-s3)
                                          ##  no checksum on these

        { 'instrument'  :  'Sperry Gyro 2 ',
          'device'      :  'tty_dgnc_0_5',
          'baud'        :   4800,
          'format'      :  'ascii',
          'subdir'      :  'gyro',
          'ext'         :  'hnc',         ## hnc or hdg (must match 'messages')
          'strings'     :  ('$HEHDT',),
          'messages'    :  ('hnc',),      ## hnc or hdg (must match 'ext')
          'opt'         :  '-t -s5'}      ## 6Hz: take every 3rd message (-s3)
                                          ##  no checksum on these
        ]



speedlog_config = {
    'instrument'        : 'nb150',
    'serial_device'     : '/dev/ttyn6',      
    'baud'              : 9600,
    'dir_output'        : '',
    'heading_offset'    : 46.0,
    'scale'             : 1.0,
    'bins'              : (1,12),

    'heading_sensor'    : 'seapath',
    'heading_msg'       : 'sea',

    'soundspeed_sensor' : None,
    'soundspeed_msg'    : 'snd',
    'nominal_soundspeed': 1536.0,
    }

#### DO NOT CHANGE the following ################

ADCPs = [A for A in ADCPs if A['instrument'] not in ignore_ADCPs]
sensors = [S for S in sensors if S['instrument'] not in ignore_ADCPs]
sensors = [S for S in sensors if S['instrument'] not in ignore_other_sensors]

